==> vixn-0.12.9.tar.bz2: vixn-0.12.9/vixn/openfile.py <==
import os.path

from . import buffers
from . import settings
from . import state
from . import vixbuf
from . import vixi18n
from . import vixview
from . import vixwin

def open_file(settings_client, cwd = None, filename = None,
        line = 0, fgparent = None, commands = None, always_reload = False):
    """ If settings_client is a window open a new tab in it. """
    # If settings_client is a real buf/view/window we want to copy its
    # settings with low priority, otherwise use priorities as loaded
    # by SettingsDefaults.
    if settings_client.get_buffer():
        priority = settings.PRIORITY_DEFAULT
    else:
        priority = None
    path = None
    buf = None
    if filename:
        if cwd:
            path = os.path.expanduser(os.path.expandvars(filename))
            if not os.path.isabs(path):
                path = os.path.join(cwd, path)
            path = os.path.normpath(path)
        else:
            path = settings_client.expandpath(filename)
        if not always_reload:
            buf = buffers.find_filename(path)
    if path:
        stt = state.state.find_file(path)
    else:
        stt = None
    if not buf:
        buf = vixbuf.VixnBuffer(settings_client, cwd, None, filename)
    if fgparent:
        buf.add_fgparent(fgparent)
    view = vixview.VixnView(buf, priority)
    if line > 0:
        view.move_cursor_to_line(line - 1)
    elif not stt:
        view.move_cursor_to_line(0)
    if isinstance(settings_client, vixwin.VixnWindow):
        #s = settings_client.view.settings.copy(priority)
        #settings.mark_all_unapplied(s)
        #settings.apply_all(view, s)
        win = settings_client
        win.new_tab(view, priority)
    else:
        win = vixwin.VixnWindow(view, priority)
    if commands:
        for c in commands:
            win.excmd.execute(c)
    win.present()
    return win

==> vixn-0.12.11.tar.bz2: vixn-0.12.11/vixn/openfile.py <==
import os.path

from . import buffers
from . import settings
from . import state
from . import vixbuf
from . import vixi18n
from . import vixview
from . import vixwin

def open_file(settings_client, cwd = None, filename = None,
        line = 0, fgparent = None, commands = None, always_reload = False):
    """ If settings_client is a window open a new tab in it. """
    # If settings_client is a real buf/view/window we want to copy its
    # settings with low priority, otherwise use priorities as loaded
    # by SettingsDefaults.
    if settings_client.get_buffer():
        priority = settings.PRIORITY_DEFAULT
    else:
        priority = None
    path = None
    buf = None
    if filename:
        if cwd:
            path = os.path.expanduser(os.path.expandvars(filename))
            if not os.path.isabs(path):
                path = os.path.join(cwd, path)
            path = os.path.realpath(os.path.normpath(path))
        else:
            path = settings_client.expandpath(filename)
        if not always_reload:
            buf = buffers.find_filename(path)
    if path:
        stt = state.state.find_file(path)
    else:
        stt = None
    if not buf:
        buf = vixbuf.VixnBuffer(settings_client, cwd, None, filename)
    if fgparent:
        buf.add_fgparent(fgparent)
    view = vixview.VixnView(buf, priority)
    if line > 0:
        view.move_cursor_to_line(line - 1)
    elif not stt:
        view.move_cursor_to_line(0)
    if isinstance(settings_client, vixwin.VixnWindow):
        #s = settings_client.view.settings.copy(priority)
        #settings.mark_all_unapplied(s)
        #settings.apply_all(view, s)
        win = settings_client
        win.new_tab(view, priority)
    else:
        win = vixwin.VixnWindow(view, priority)
    if commands:
        for c in commands:
            win.excmd.execute(c)
    win.present()
    return win
